package de.fitko.fitconnect;

import de.fitko.fitconnect.api.domain.model.submission.SubmissionRequest;
import de.fitko.fitconnect.client.SenderClient;
import de.fitko.fitconnect.client.SubscriberClient;

import java.util.Collections;
import java.util.List;
import java.util.UUID;

public class TestRunner {

    public static void main(String[] args) {
        senderSample();
    }

    private static void senderSample() {

        // straight call in one go
        SenderClient.build().send(UUID.randomUUID(), Collections.emptyList());
        SenderClient.build().send(UUID.randomUUID(), Collections.emptyList(), "some json or xml");

        // Without data
        SenderClient.build()
                .withDestination(UUID.randomUUID())
                .withAttachments(Collections.emptyList())
                .submit();

        // With data
        SenderClient.build()
                .withDestination(UUID.randomUUID())
                .withAttachments(Collections.emptyList())
                .withData("some json or xml")
                .submit();
    }

    private static void subscriberSample() {

        var clientId = "781f6213-0f0f-4a79-9372-e7187ffda98b";
        var secret = "PnzR8Vbmhpv_VwTkT34wponqXWK8WBm-LADlryYdV4o";


        // #1 authenticate
        var authenticatedClient = SubscriberClient.builder().authenticate(clientId, secret);

        // #2 poll for available submissions
        List<SubmissionRequest> availableSubmissions = authenticatedClient.getAvailableSubmissions("someDestinationId");

        // #3 get a submission and its data
        var confirmedSubmission = authenticatedClient
                .requestSubmission(SubmissionRequest.builder().build())
                .requestMetadata()
                .requestAttachments()
                .confirmSubmission();

        // access request submission data
        var attachments = confirmedSubmission.getAttachments();
        var metadata = confirmedSubmission.getMetadata();

    }

}
